package com.xtd.project.assets.service;

import java.util.List;
import com.xtd.project.assets.domain.DbAssetsStockOut;

/**
 * 资产出库Service接口
 *
 * @author xtd
 * @date 2020-04-16
 */
public interface IDbAssetsStockOutService
{
    /**
     * 查询资产出库
     *
     * @param aId 资产出库ID
     * @return 资产出库
     */
    public DbAssetsStockOut selectDbAssetsStockOutById(Long aId);

    /**
     * 查询资产出库列表
     *
     * @param dbAssetsStockOut 资产出库
     * @return 资产出库集合
     */
    public List<DbAssetsStockOut> selectDbAssetsStockOutList(DbAssetsStockOut dbAssetsStockOut);

    /**
     * 新增资产出库
     *
     * @param dbAssetsStockOut 资产出库
     * @return 结果
     */
    public int insertDbAssetsStockOut(DbAssetsStockOut dbAssetsStockOut);

    /**
     * 修改资产出库
     *
     * @param dbAssetsStockOut 资产出库
     * @return 结果
     */
    public int updateDbAssetsStockOut(DbAssetsStockOut dbAssetsStockOut);

    /**
     * 批量删除资产出库
     *
     * @param aIds 需要删除的资产出库ID
     * @return 结果
     */
    public int deleteDbAssetsStockOutByIds(Long[] aIds);

    /**
     * 删除资产出库信息
     *
     * @param aId 资产出库ID
     * @return 结果
     */
    public int deleteDbAssetsStockOutById(Long aId);

    void commit(Long aId, String processId);

    void recommit(DbAssetsStockOut dbAssetsStockOut);
}
